@@ -31,7 +31,7 @@ from zntrack.zn.dependencies import NodeAttribute, getdeps
 log = logging.getLogger(__name__)
 
 EXCEPTION_OR_LST_EXCEPTIONS = typing.Union[
-    typing.Type[Exception], typing.Collection[typing.Type[Exception]]
+    typing.Type[Exception], typing.Collection[typing.Type[Exception]], None
 ]
 
 
@@ -92,10 +92,7 @@ def _handle_nodes_as_methods(nodes: dict):
     """
     for node in nodes.values():
         if node is not None:
-            node.write_graph(
-                run=True,
-                call_args=f".load(name='{node.node_name}').save(hash_only=True)",
-            )
+            node.write_graph(run=True, call_args=f"--name={node.node_name} --hash-only")
 
 
 BaseNodeTypeT = typing.TypeVar("BaseNodeTypeT", bound="Node")
@@ -588,8 +585,9 @@ class Node(NodeBase, metaclass=LoadViaGetItem):
         Use 'dvc status' to check, if the stage needs to be rerun.
 
         """
-        self.nwd.mkdir(parents=True, exist_ok=True)
-        _handle_nodes_as_methods(self.zntrack.collect(ZnNodes))
+        if not dry_run:
+            self.nwd.mkdir(parents=True, exist_ok=True)
+            _handle_nodes_as_methods(self.zntrack.collect(ZnNodes))
 
         if silent:
             log.warning(
@@ -611,8 +609,9 @@ class Node(NodeBase, metaclass=LoadViaGetItem):
 
         # Jupyter Notebook
         nb_name = utils.update_nb_name(nb_name)
-        if nb_name is not None and notebook:
-            self.convert_notebook(nb_name)
+        if not dry_run:
+            if nb_name is not None and notebook:
+                self.convert_notebook(nb_name)
 
         custom_args = []
         dependencies = []
@@ -649,7 +648,7 @@ class Node(NodeBase, metaclass=LoadViaGetItem):
             custom_args += pair
 
         if call_args is None:
-            call_args = f".load(name='{self.node_name}').run_and_save()"
+            call_args = f"--name={self.node_name}"
 
         script = prepare_dvc_script(
             node_name=self.node_name,
@@ -662,8 +661,8 @@ class Node(NodeBase, metaclass=LoadViaGetItem):
         )
 
         # Add command to run the script
-
-        self.save()
+        if not dry_run:
+            self.save()
 
         log.debug(
             "If you are using a jupyter notebook, you may not be able to see the "
@@ -690,7 +689,11 @@ class Node(NodeBase, metaclass=LoadViaGetItem):
 
     @contextlib.contextmanager
     def operating_directory(
-        self, prefix="ckpt", remove_on: EXCEPTION_OR_LST_EXCEPTIONS = None
+        self,
+        prefix="ckpt",
+        remove_on: EXCEPTION_OR_LST_EXCEPTIONS = None,
+        move_on: EXCEPTION_OR_LST_EXCEPTIONS = Exception,
+        disable: bool = None,
     ) -> bool:
         """Work in an operating directory until successfully finished.
 
@@ -712,6 +715,13 @@ class Node(NodeBase, metaclass=LoadViaGetItem):
         remove_on: Exception or list of Exceptions, default = None
             If one of the exceptions in 'remove_on' is raised, the operating directory
              will be removed. Otherwise, it will remain and reused upton the next run.
+        move_on: Exception, default = Exception
+            If one of the exceptions in 'move_on' is raised, the operating directories
+            content is moved to $nwd$ and the directory will be removed.
+            This helps, in the case of an error to not restart from an already
+            failed data point.
+        disable: bool, default = False
+            Disable the operating directory. Yields True.
 
 
         Yields
@@ -719,13 +729,20 @@ class Node(NodeBase, metaclass=LoadViaGetItem):
         new_ckpt: bool
             True if creating a new checkpoint. False if the checkpoint already existed.
         """
+        if disable is None:
+            disable = utils.config.disable_operating_directory
+        if disable:
+            yield True
+            return
+
         nwd = self.nwd
         nwd_new = self.nwd.with_name(f"{prefix}_{self.nwd.name}")
         nwd_is_new = not nwd_new.exists()
 
         remove = False
-        if not isinstance(remove_on, list):
-            remove_on = [remove_on] if remove_on else []
+        move = False
+        remove_on = utils.utils.convert_to_list(remove_on)
+        move_on = utils.utils.convert_to_list(move_on)
 
         if self._run_and_save:
             utils.update_gitignore(prefix=prefix)
@@ -747,8 +764,9 @@ class Node(NodeBase, metaclass=LoadViaGetItem):
                 yield nwd_is_new
             except Exception as err:
                 log.warning("Node execution was interrupted.")
-                if any(isinstance(err, e) for e in remove_on):
-                    remove = True
+                remove = any(isinstance(err, e) for e in remove_on)
+                move = any(isinstance(err, e) for e in move_on)
+                # finally -> ...
                 raise err
             finally:
                 # Save e.g. `zn.outs` before stopping.
@@ -757,11 +775,12 @@ class Node(NodeBase, metaclass=LoadViaGetItem):
                 if remove:
                     log.info(f"Removing operating directory: {nwd_new}")
                     shutil.rmtree(nwd_new)
+                elif move:
+                    log.info(f"Moving files from '{nwd_new}' to {nwd}")
+                    utils.move_nwd(nwd_new, nwd)
 
             log.info(f"Finished successfully. Moving files from {nwd_new} to {nwd}")
-            shutil.rmtree(nwd)
-            shutil.copytree(nwd_new, nwd, copy_function=os.link)
-            shutil.rmtree(nwd_new)
+            utils.move_nwd(nwd_new, nwd)
         else:
             # if not inside 'run_and_save' no directory should be created. ?!?!?!
             self.nwd = nwd_new
