@@ -1,4 +1,4 @@
-"""Collection of DVC options
+"""Collection of DVC options.
 
 Based on ZnTrackOption python descriptors this gives access to them being used
 to define e.g. dependencies
@@ -8,12 +8,13 @@ Examples
 >>> from zntrack import Node, dvc
 >>> class HelloWorld(Node)
 >>>     vars = dvc.params()
+
 """
 import logging
+import pathlib
 
 from zntrack import utils
-from zntrack.core.zntrackoption import ZnTrackOption
-from zntrack.dvc.custom_base import PlotsModifyOption
+from zntrack.dvc.custom_base import DVCOption, PlotsModifyOption
 
 log = logging.getLogger(__name__)
 
@@ -22,23 +23,19 @@ log = logging.getLogger(__name__)
 # detailed explanations on https://dvc.org/doc/command-reference/run#options
 
 
-class params(ZnTrackOption):
-    """Identify DVC option
+class params(DVCOption):  # pylint: disable=invalid-name
+    """Identify DVC option.
 
     See https://dvc.org/doc/command-reference/run#options for more information
      on the available options
     """
 
-    zn_type = utils.ZnTypes.PARAMS
-    file = utils.Files.params
-
-    @utils.deprecated(reason="This Option was moved to zntrack.zn.params", version="v0.3")
-    def __init__(self, default_value=None):
-        super().__init__(default_value)
+    zn_type = utils.ZnTypes.DVC
+    file = utils.Files.zntrack
 
 
-class deps(ZnTrackOption):
-    """Identify DVC option
+class deps(DVCOption):  # pylint: disable=invalid-name
+    """Identify DVC option.
 
     See https://dvc.org/doc/command-reference/run#options for more information
      on the available options
@@ -47,18 +44,32 @@ class deps(ZnTrackOption):
     zn_type = utils.ZnTypes.DEPS
     file = utils.Files.zntrack
 
-    def __get__(self, instance, owner):
-        """Use load_node_dependency before returning the value"""
-        if instance is None:
-            return self
-        value = super().__get__(instance, owner)
-        value = utils.utils.load_node_dependency(value, log_warning=True)
-        setattr(instance, self.name, value)
-        return value
+    def __set__(self, instance, value):
+        """Add a type check."""
+
+        def check_correct_type(x):
+            """Check if correct type is passed."""
+            # TODO make this check available for more DVCOptions.
+            if not (isinstance(x, (str, pathlib.Path)) or (x is None)):
+                if hasattr(x, "node_name"):
+                    raise ValueError(
+                        f"Found Node instance ({x}) in dvc.deps(), use zn.deps() instead."
+                    )
+                raise ValueError(
+                    f"Found type '{type(x)}', but 'dvc.deps' only supports lists/tuples"
+                    " of string or Path."
+                )
+
+        if isinstance(value, (list, tuple)):
+            [check_correct_type(x) for x in value]
+        else:
+            check_correct_type(value)
+
+        super().__set__(instance, value)
 
 
-class outs(ZnTrackOption):
-    """Identify DVC option
+class outs(DVCOption):  # pylint: disable=invalid-name
+    """Identify DVC option.
 
     See https://dvc.org/doc/command-reference/run#options for more information
      on the available options
@@ -68,8 +79,8 @@ class outs(ZnTrackOption):
     file = utils.Files.zntrack
 
 
-class checkpoints(ZnTrackOption):
-    """Identify DVC option
+class checkpoints(DVCOption):  # pylint: disable=invalid-name
+    """Identify DVC option.
 
     See https://dvc.org/doc/command-reference/run#options for more information
      on the available options
@@ -79,8 +90,8 @@ class checkpoints(ZnTrackOption):
     file = utils.Files.zntrack
 
 
-class outs_no_cache(ZnTrackOption):
-    """Identify DVC option
+class outs_no_cache(DVCOption):  # pylint: disable=invalid-name
+    """Identify DVC option.
 
     See https://dvc.org/doc/command-reference/run#options for more information
      on the available options
@@ -90,8 +101,8 @@ class outs_no_cache(ZnTrackOption):
     file = utils.Files.zntrack
 
 
-class outs_persistent(ZnTrackOption):
-    """Identify DVC option
+class outs_persistent(DVCOption):  # pylint: disable=invalid-name
+    """Identify DVC option.
 
     See https://dvc.org/doc/command-reference/run#options for more information
      on the available options
@@ -101,8 +112,8 @@ class outs_persistent(ZnTrackOption):
     file = utils.Files.zntrack
 
 
-class metrics(ZnTrackOption):
-    """Identify DVC option
+class metrics(DVCOption):  # pylint: disable=invalid-name
+    """Identify DVC option.
 
     See https://dvc.org/doc/command-reference/run#options for more information
      on the available options
@@ -112,8 +123,8 @@ class metrics(ZnTrackOption):
     file = utils.Files.zntrack
 
 
-class metrics_no_cache(ZnTrackOption):
-    """Identify DVC option
+class metrics_no_cache(DVCOption):  # pylint: disable=invalid-name
+    """Identify DVC option.
 
     See https://dvc.org/doc/command-reference/run#options for more information
      on the available options
@@ -123,8 +134,8 @@ class metrics_no_cache(ZnTrackOption):
     file = utils.Files.zntrack
 
 
-class plots(PlotsModifyOption):
-    """Identify DVC option
+class plots(PlotsModifyOption):  # pylint: disable=invalid-name
+    """Identify DVC option.
 
     See https://dvc.org/doc/command-reference/run#options for more information
      on the available options
@@ -134,8 +145,8 @@ class plots(PlotsModifyOption):
     file = utils.Files.zntrack
 
 
-class plots_no_cache(ZnTrackOption):
-    """Identify DVC option
+class plots_no_cache(PlotsModifyOption):  # pylint: disable=invalid-name
+    """Identify DVC option.
 
     See https://dvc.org/doc/command-reference/run#options for more information
      on the available options
@@ -143,3 +154,17 @@ class plots_no_cache(ZnTrackOption):
 
     zn_type = utils.ZnTypes.DVC
     file = utils.Files.zntrack
+
+
+options = [
+    params,
+    deps,
+    outs,
+    checkpoints,
+    outs_no_cache,
+    outs_persistent,
+    metrics,
+    metrics_no_cache,
+    plots,
+    plots_no_cache,
+]
