@@ -1,3 +1,4 @@
+"""DVC Interface through ZnTrack."""
 import copy
 import dataclasses
 import json
@@ -8,12 +9,16 @@ import subprocess
 from pathlib import Path
 from typing import List
 
+import tqdm
+
+from zntrack import utils
+
 log = logging.getLogger(__name__)
 
 
 @dataclasses.dataclass
 class Experiment:
-    """Collection of the output of dvc exp show --show-json"""
+    """Collection of the output of dvc exp show --show-json."""
 
     name: str
     hash: str
@@ -28,18 +33,23 @@ class Experiment:
 
 
 class DVCInterface:
-    """A Python Interface for DVC"""
+    """A Python Interface for DVC."""
 
+    @utils.deprecated(
+        reason=(
+            "The 'DVCInterface' is currently unmaintained and might be removed "
+            "in a future release. It might not be compatible with newer DVC versions"
+        ),
+        version="0.4.3",
+    )
     def __init__(self):
-        """DVCInterface for getting experiments and loading data from
-        multiple experiments
-        """
+        """DVCInterface for getting experiments and loading data."""
         self._experiments = None
         self._exp_list = None
 
     @property
     def experiments(self) -> dict:
-        """Get all experiments in json format"""
+        """Get all experiments in json format."""
         if self._experiments is None:
             # Only load it once! This speeds things up. If experiments change
             # during the lifetime of this instance they won't be
@@ -57,13 +67,12 @@ class DVCInterface:
 
     @property
     def exp_list(self) -> List[Experiment]:
-        """Get all experiment names and hash values for the current commit
+        """Get all experiment names and hash values for the current commit.
 
         Returns
         -------
         list[Experiment]: A list containing experiment dataclasses
         """
-
         if self._exp_list is None:
             experiments = copy.deepcopy(self.experiments)
             experiments.pop("workspace")
@@ -79,14 +88,14 @@ class DVCInterface:
         return self._exp_list
 
     def _reset(self):
-        """Reset properties to be loaded again"""
+        """Reset properties to be loaded again."""
         self._experiments = None
         self._exp_list = None
 
     def load_files_into_directory(
         self, files: List[str], path: str = "experiments", experiments: List[str] = None
     ):
-        """Save files from multiple experiments in a single directory
+        """Save files from multiple experiments in a single directory.
 
         Create a parent directory "path" that contains subdirectories for each
         experiment where the requested files are saved.
@@ -105,17 +114,19 @@ class DVCInterface:
         path = Path(path)
         path.mkdir(exist_ok=True, parents=True)
         if experiments is None:
-            exp_list = self.exp_list
+            exp_list = [x for x in self.exp_list if x.name not in ("master", "main")]
         else:
             exp_list = [x for x in self.exp_list if x.name in experiments]
 
-        for experiment in exp_list:
+        progress_bar = tqdm.tqdm(exp_list)
+
+        for experiment in progress_bar:
+            progress_bar.set_description(f"Processing {experiment.name}")
             for file in files:
                 file = pathlib.Path(file)
                 out_path = path / experiment.name
                 out_path.mkdir(parents=True, exist_ok=True)
                 cmd = [
-                    "dvc",
                     "get",
                     ".",
                     file.as_posix(),
@@ -125,4 +136,4 @@ class DVCInterface:
                     out_path.as_posix(),
                 ]
                 log.debug(f"DVC command: {cmd}")
-                subprocess.run(cmd)
+                utils.run_dvc_cmd(cmd)
