@@ -1,3 +1,4 @@
+"""ZnTrack file I/O."""
 import json
 import logging
 import pathlib
@@ -10,21 +11,25 @@ log = logging.getLogger(__name__)
 
 
 def read_file(file: pathlib.Path) -> dict:
-    """Read a json/yaml file without the znjson.Decoder
+    """Read a json/yaml file without the znjson.Decoder.
 
     Parameters
     ----------
     file: pathlib.Path
         The file to read
 
+    Raises
+    ------
+    ValueError: if the file type is not supported
+    FileNotFoundError: if the file does not exist
+
     Returns
     -------
     dict:
         Content of the json/yaml file
     """
     if file.suffix in [".yaml", ".yml"]:
-        with file.open("r") as f:
-            file_content = yaml.safe_load(f)
+        file_content = yaml.safe_load(file.read_text())
     elif file.suffix == ".json":
         file_content = json.loads(file.read_text())
     else:
@@ -33,7 +38,7 @@ def read_file(file: pathlib.Path) -> dict:
 
 
 def write_file(file: pathlib.Path, value: dict, mkdir: bool = True):
-    """Save dict to file
+    """Save dict to file.
 
     Store dictionary to json or yaml file
 
@@ -58,7 +63,7 @@ def write_file(file: pathlib.Path, value: dict, mkdir: bool = True):
 
 
 def clear_config_file(file: pathlib.Path, node_name: str):
-    """Clear the entries in the files for the given node name
+    """Clear the entries in the files for the given node name.
 
     Parameters
     ----------
@@ -82,7 +87,7 @@ def update_config_file(
     value_name: typing.Union[str, None],
     value,
 ):
-    """Update a configuration file
+    """Update a configuration file.
 
     The file structure for node_name is not None is something like
     >>> {node_name: {value_name: value}}
@@ -127,3 +132,26 @@ def update_config_file(
         file_content[node_name] = node_content
     write_file(file, value=file_content)
     log.debug(f"Update <{file}> with: {file_content}")
+
+
+def update_desc(file: pathlib.Path, node_name: str, desc: str):
+    """Update the 'dvc.yaml' with a description."""
+    if desc is not None:
+        file_content = read_file(file)
+        file_content["stages"][node_name]["desc"] = desc
+        write_file(file, value=file_content)
+
+
+def update_meta(file: pathlib.Path, node_name: str, data: dict):
+    """Update the file (dvc.yaml) given the Node for 'meta' key with the data."""
+    if data is not None:
+        file_content = read_file(file)
+        meta_data = file_content["stages"][node_name].get("meta", {})
+        if not isinstance(meta_data, dict):
+            raise ValueError(
+                "The 'meta' key in the 'dvc.yaml' is not empty or was otherwise modified."
+                " To use 'zntrack.meta' it is not possible to use that field otherwise."
+            )
+        meta_data.update(data)
+        file_content["stages"][node_name]["meta"] = meta_data
+        write_file(file, value=file_content)
