@@ -1,8 +1,12 @@
+"""ZnTrack structs and LazyOption."""
 import enum
 
 
 class LazyOption:
+    """A LazyOption for lazy loading."""
+
     def __init__(self):
+        """Prohibit instantiation of LazyOption."""
         raise ValueError(
             "Can not initialize LazyOption. If you expected something else open an "
             "issue at https://github.com/zincware/ZnTrack and describe how you got here."
@@ -10,11 +14,12 @@ class LazyOption:
 
 
 class ZnTypes(enum.Enum):
-    """Collection of ZnTrack Types to identify descriptors beyond their dvc option
+    """Collection of ZnTrack Types to identify descriptors beyond their dvc option.
 
     Attributes
     ----------
     results: most zn.<options> like zn.outs() / zn.metrics() use this one
+    HASH: special type which will always be saved even if _is_attribute = True
     """
 
     DEPS = enum.auto()
@@ -25,12 +30,23 @@ class ZnTypes(enum.Enum):
     ITERABLE = enum.auto()
     RESULTS = enum.auto()
     PLOTS = enum.auto()
+    HASH = enum.auto()
+    META = enum.auto()
 
 
 FILE_DVC_TRACKED = [ZnTypes.DVC]
 # if the getattr(instance, self.name) is an affected file,
 # e.g. the dvc.<outs> is a file / list of files
-VALUE_DVC_TRACKED = [ZnTypes.RESULTS, ZnTypes.METADATA, ZnTypes.PLOTS]
+
+VALUE_DVC_TRACKED = [
+    ZnTypes.RESULTS,
+    ZnTypes.METADATA,
+    ZnTypes.PLOTS,
+    ZnTypes.HASH,
+]
+
+# The data is not tracked / used via any DVC command
+GIT_TRACKED = [ZnTypes.META]
 
 
 # if the internal file,
@@ -38,6 +54,8 @@ VALUE_DVC_TRACKED = [ZnTypes.RESULTS, ZnTypes.METADATA, ZnTypes.PLOTS]
 
 
 class DVCOptions(enum.Enum):
+    """Available DVCOptions."""
+
     # Use enum over dataclass because it is iterable
     PARAMS = "params"
     DEPS = "deps"
