@@ -1,37 +1,33 @@
-"""Description: zn.<option>
+"""Description: zn.<option>.
 
 The following can be used to store e.g. metrics directly without
 defining and writing to a file explicitly. For more information on the individual methods
 see https://dvc.org/doc/command-reference/run#options
 
 """
+
+import contextlib
 import logging
 
 from zntrack import utils
 from zntrack.core.zntrackoption import ZnTrackOption
 from zntrack.zn.method import Method
+from zntrack.zn.nodes import Nodes
 from zntrack.zn.split_option import SplitZnTrackOption
+from zntrack.zn.zn_hash import Hash
 
 log = logging.getLogger(__name__)
 
-__all__ = [Method.__name__]
+__all__ = [Method.__name__, Hash.__name__, Nodes.__name__]
 
-try:
+with contextlib.suppress(ImportError):
     from .plots import plots
 
     __all__ += [plots.__name__]
-except ImportError:
-    pass
 
 
-# module class definitions to be used via zn.<option>
-# detailed explanations on https://dvc.org/doc/command-reference/run#options
-# with the exception that these will be loaded to memory when.
-# for direct file references use dvc.<option> instead.
-
-
-class outs(ZnTrackOption):
-    """Identify DVC option
+class outs(ZnTrackOption):  # pylint: disable=invalid-name
+    """Identify DVC option.
 
     See https://dvc.org/doc/command-reference/run#options for more information
      on the available options
@@ -40,8 +36,8 @@ class outs(ZnTrackOption):
     zn_type = utils.ZnTypes.RESULTS
 
 
-class deps(ZnTrackOption):
-    """Identify DVC option
+class deps(ZnTrackOption):  # pylint: disable=invalid-name
+    """Identify DVC option.
 
     See https://dvc.org/doc/command-reference/run#options for more information
      on the available options
@@ -50,8 +46,8 @@ class deps(ZnTrackOption):
     zn_type = utils.ZnTypes.DEPS
     file = utils.Files.zntrack
 
-    def __get__(self, instance, owner):
-        """Use load_node_dependency before returning the value"""
+    def __get__(self, instance, owner=None, serialize=False):
+        """Use load_node_dependency before returning the value."""
         if instance is None:
             return self
         value = super().__get__(instance, owner)
@@ -60,8 +56,8 @@ class deps(ZnTrackOption):
         return value
 
 
-class metrics(ZnTrackOption):
-    """Identify DVC option
+class metrics(ZnTrackOption):  # pylint: disable=invalid-name
+    """Identify DVC option.
 
     See https://dvc.org/doc/command-reference/run#options for more information
      on the available options
@@ -70,9 +66,26 @@ class metrics(ZnTrackOption):
     dvc_option = utils.DVCOptions.METRICS_NO_CACHE.value
     zn_type = utils.ZnTypes.RESULTS
 
+    def __init__(self, *args, cache: bool = False, **kwargs):
+        """Parse additional attributes for plots.
 
-class params(SplitZnTrackOption):
-    """Identify DVC option
+        Parameters
+        ----------
+        cache: bool, default = False
+            Store the result of 'zn.metrics' inside the DVC cache.
+            This can e.g. be useful it the metrics are large and should not be GIT tracked
+        args:
+            positional arguments passed super.__init__
+        kwargs:
+            keyword arguments passed super.__init__
+        """
+        if cache:
+            self.dvc_option = utils.DVCOptions.METRICS.value
+        super().__init__(*args, **kwargs)
+
+
+class params(SplitZnTrackOption):  # pylint: disable=invalid-name
+    """Identify DVC option.
 
     See https://dvc.org/doc/command-reference/run#options for more information
      on the available options
@@ -82,18 +95,8 @@ class params(SplitZnTrackOption):
     file = utils.Files.params
 
 
-class iterable(ZnTrackOption):
-    """Special ZnTrack option
-
-    This option defines an iterable parameter for spawning nodes.
-    """
-
-    dvc_option = utils.DVCOptions.PARAMS.value
-    zn_type = utils.ZnTypes.ITERABLE
-
-
-class metadata(ZnTrackOption):
-    """Special ZnTrack option
+class metadata(ZnTrackOption):  # pylint: disable=invalid-name
+    """Special ZnTrack option.
 
     This option defines a <metrics_no_cache> output that is used by ZnTracks metadata
     collectors.
